@@ -1688,10 +1688,11 @@ def test_external_write():
 def test_unit_scale():
     """Test numeric `unit_scale`"""
     with closing(StringIO()) as our_file:
-        for _ in tqdm(_range(100), unit_scale=9, file=our_file):
+        for _ in tqdm(_range(9), unit_scale=9, file=our_file,
+                      miniters=1,  mininterval=0):
             pass
         out = our_file.getvalue()
-        assert '900/900' in out
+        assert '81/81' in out
 
 
 @with_setup(pretest, posttest)
@@ -1711,26 +1712,30 @@ def test_threading():
 def test_bool():
     """Test boolean cast"""
     def internal(our_file, disable):
-        with tqdm(total=10, file=our_file, disable=disable) as t:
+        kwargs = dict(file=our_file, disable=disable)
+        with trange(10, **kwargs) as t:
             assert t
-        with tqdm(total=0, file=our_file, disable=disable) as t:
+        with trange(0, **kwargs) as t:
             assert not t
-        with trange(10, file=our_file, disable=disable) as t:
+        with tqdm(total=10, **kwargs) as t:
+            assert bool(t)
+        with tqdm(total=0, **kwargs) as t:
+            assert not bool(t)
+        with tqdm([], **kwargs) as t:
+            assert not t
+        with tqdm([0], **kwargs) as t:
             assert t
-        with trange(0, file=our_file, disable=disable) as t:
-            assert not t
-        with tqdm([], file=our_file, disable=disable) as t:
-            assert not t
-        with tqdm([0], file=our_file, disable=disable) as t:
+        with tqdm((x for x in []), **kwargs) as t:
             assert t
-        with tqdm(file=our_file, disable=disable) as t:
+        with tqdm((x for x in [1,2,3]), **kwargs) as t:
+            assert t
+        with tqdm(**kwargs) as t:
             try:
                 print(bool(t))
             except TypeError:
                 pass
             else:
-                raise TypeError(
-                    "Expected tqdm() with neither total nor iterable to fail")
+                raise TypeError("Expected bool(tqdm()) to fail")
 
     # test with and without disable
     with closing(StringIO()) as our_file:
